==> aws-java-sdk-machinelearning-1.10.15-sources.jar: com/amazonaws/services/machinelearning/model/transform/CreateRealtimeEndpointResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.machinelearning.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.machinelearning.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * CreateRealtimeEndpointResult JSON Unmarshaller
 */
public class CreateRealtimeEndpointResultJsonUnmarshaller implements
        Unmarshaller<CreateRealtimeEndpointResult, JsonUnmarshallerContext> {

    public CreateRealtimeEndpointResult unmarshall(
            JsonUnmarshallerContext context) throws Exception {
        CreateRealtimeEndpointResult createRealtimeEndpointResult = new CreateRealtimeEndpointResult();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("MLModelId", targetDepth)) {
                    context.nextToken();
                    createRealtimeEndpointResult
                            .setMLModelId(StringJsonUnmarshaller.getInstance()
                                    .unmarshall(context));
                }
                if (context.testExpression("RealtimeEndpointInfo", targetDepth)) {
                    context.nextToken();
                    createRealtimeEndpointResult
                            .setRealtimeEndpointInfo(RealtimeEndpointInfoJsonUnmarshaller
                                    .getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return createRealtimeEndpointResult;
    }

    private static CreateRealtimeEndpointResultJsonUnmarshaller instance;

    public static CreateRealtimeEndpointResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new CreateRealtimeEndpointResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-machinelearning-1.11.29-sources.jar: com/amazonaws/services/machinelearning/model/transform/CreateRealtimeEndpointResultJsonUnmarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.machinelearning.model.transform;

import java.util.Map;
import java.util.Map.Entry;
import java.math.*;
import java.nio.ByteBuffer;

import com.amazonaws.services.machinelearning.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * CreateRealtimeEndpointResult JSON Unmarshaller
 */
public class CreateRealtimeEndpointResultJsonUnmarshaller implements
        Unmarshaller<CreateRealtimeEndpointResult, JsonUnmarshallerContext> {

    public CreateRealtimeEndpointResult unmarshall(
            JsonUnmarshallerContext context) throws Exception {
        CreateRealtimeEndpointResult createRealtimeEndpointResult = new CreateRealtimeEndpointResult();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("MLModelId", targetDepth)) {
                    context.nextToken();
                    createRealtimeEndpointResult.setMLModelId(context
                            .getUnmarshaller(String.class).unmarshall(context));
                }
                if (context.testExpression("RealtimeEndpointInfo", targetDepth)) {
                    context.nextToken();
                    createRealtimeEndpointResult
                            .setRealtimeEndpointInfo(RealtimeEndpointInfoJsonUnmarshaller
                                    .getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return createRealtimeEndpointResult;
    }

    private static CreateRealtimeEndpointResultJsonUnmarshaller instance;

    public static CreateRealtimeEndpointResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new CreateRealtimeEndpointResultJsonUnmarshaller();
        return instance;
    }
}
